@@ -7,7 +7,6 @@
 #include "cachetest.h"
 #include "libkcddb/cache.h"
 
-#include "libkcddb/cdinfo.h"
 #include "libkcddb/client.h"
 #include "config-musicbrainz.h"
 #include <QTest>
@@ -38,7 +37,7 @@ void CacheTest::initTestCase()
 
   for (int i=0; i<10; i++)
   {
-    m_info.track(i).set(Title, QString().leftJustified(30*(i+1), 'a'+i));
+    m_info.track(i).set(Title, QString().leftJustified(30*(i+1), QChar('a'+i)));
   }
 
 }
